#
# spec file for package gyp
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nurenberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gyp
Version:        0+git.20240207
Release:        1.1
Summary:        Generate Your Projects
License:        BSD-3-Clause
URL:            https://gyp.gsrc.io
Source:         %{name}-%{version}.tar.gz
Patch0:         gyp-rpmoptflags.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
Requires:       ninja
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       gyp = %{version}
Obsoletes:      gyp < %{version}
BuildArch:      noarch
%python_subpackages

%description
GYP is a tool to generates native Visual Studio, Xcode and SCons and/or make
build files from a platform-independent input format. Its syntax is a universal
cross-platform build representation that still allows sufficient per-platform
flexibility to accommodate irreconcilable differences

%prep
%autosetup -p0
for i in $(find pylib -name '*.py'); do
	sed -e '\,#![ \t]*/.*python,{d}' $i > $i.new && touch -r $i $i.new && mv $i.new $i
done
sed -i '/^#!/d' ./pylib/%{name}/*.py
sed -i '/^#!/d' ./pylib/%{name}/generator/*.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/gyp
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative gyp

%postun
%python_uninstall_alternative gyp

%files %{python_files}
%license LICENSE
%doc AUTHORS
%python_alternative %{_bindir}/gyp
%{python_sitelib}/gyp
%{python_sitelib}/gyp-*-info

%changelog
* Tue Dec 10 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 0+git.20240207:
  * Make gyp.el conform to conventional library format
  * Correct toolset version for Visual Studio 2019
  * Added support for constructing Xcode project files that import XCFrameworks.
* Fri May  5 2023 martin.sirringhaus@suse.com
- Update to version 0+git.20230301:
  * Add SpectreMitigation attribute for msvs
  * Import OrderedDict from collections, not collections_abc
  * gyp: default to python3 if available
  * MSVSVersion.py: add support for VS2019 and VS2022
  * msvs_emulation.py: avoid string-int/float comparisons
  * Fix python3 compatibility on windows
  * msvs_emulation.py: allow skipping path normalization
  * Use six.moves.collections_abc where appropriate (boo#1211137)
  * Remove Travis integration, since GYP is now idle.
* Wed Apr 28 2021 Martin Pluskal <mpluskal@suse.com>
- Use obs service
- Small spec file cleanup
* Mon Aug 31 2020 Martin Pluskal <mpluskal@suse.com>
- Convert to singlespec
- Update to version 0+git.20200512:
  * Add support for CLANG_ENABLE_OBJC_WEAK
  * Prevent propogation to configurations of nested 'dependent-settings' directives
  * Add .tbd to the .xcodeproj generator’s extension map
  * fix encoding issues with inputs for better Python 3 support
  * fix make output checks under C locale
  * Fix Python 3 incompatibilities
  * Add missing b'' qualifier from da63cb0f.
  * Misc python3 fixes in xcode_emulation.
  * Fix incorrect depfile path relativization
  * Add flake8 checks to travis configuration.
  * Changes for windows and easy xml to get gyp to run under python 3.
  * More miscellaneous fixes for Python3 compatibility.
  * src,win: add VS2019 version
  * Fixes needed for Python3 on Win32.
  * Fix one dangling utf8 decode call needed for python 3.
  * Mostly mechanical changes for Python3 support.
  * Update simple_copy.py for Python3 types.
  * Use ast module instead of compiler module for parsing files.
  * Make Visual Studio 2017 Community Edition work w/ GYP.
  * Add a copyright header to TestCmd.py.
  * Fix issue with missing resources in Xcode ui tests targets.
  * Patch GYP so that building with Xcode 10 works.
  * infra: remove cq.cfg, which is no longer used.
  * Make Travis build only the master branch
  * Disable some tests that fail on bots to try to get a green build
  * and try clang
  * readd osx
  * try a wrapper script
  * see if ninja is getting pulled
  * see if ninja is getting pulled
  * try other order for sync:
  * try exporting PATH and only build ninja for now
  * fiddling with directories
  * set +x  on buildbot/travis-checkout.sh
  * add copyright to .sh
  * .
  * osx
  * .
  * Add prototype of Travis config
* Thu Nov  2 2017 mpluskal@suse.com
- Update to version 0+git.20171012:
  * Remove Rietveld CQ config.
  * Flip to LUCI for tryjobs.
  * Provide backward compatibility for python 2.7.6 on z/OS
  * Add LIBS to the link command on z/OS
  * Change z/OS platform flavor name based on python 2.7.13
* Mon Sep  4 2017 mpluskal@suse.com
- Update to version 0+git.20170904:
  * [win-test] loosen win-driver-target-type test
  * [win] Add support for MS VS2017 (via Registry)
  * Update test/no-cpp/gyptest-no-cpp.
  * Disable a bunch of tests on Mac.
  * Clean up gyptest.py.
  * win,ninja: ninja generator better on windows
  * Disable flaky test/copies/gyptest-all under msvs.
  * Fix MSVC++ 32-on-32 builds after b62d04ff85e6
  * win ninja/make: Always use a native compiler executable with MSVS 2017
  * win: mkdir even when copying directory
  * mac_tool.py: Handle non-zero ibtool return code.
  * gyp: update xml string encoding conversion
  * gyp: show descriptive Windows SDK detection error
  * Support z/OS platform
  * make,ninja: Add support for an LDFLAGS_host environment variable.
* Wed Apr  5 2017 mpluskal@suse.com
- Update to version 0+git.20170303:
  * Set up a CQ for gyp
  * Make Gerrit the default code review system for gyp
  * CQ config: add gerrit CQAbility verifier.
* Fri Jan 13 2017 mpluskal@suse.com
- Update to version 0+git.20161117:
  * fix common "NameError"s
  * Hash intermediate file name to avoid ENAMETOOLONG
  * msvs: Allow target platform version without WinRT
  * Update shared library extension on AIX to .a.
* Sun Aug 28 2016 mpluskal@suse.com
- Update to version 0+git.20160810:
  * Adds support for a new target spec: 'mac_xcuitest_bundle'. This allows us to create UI testing bundles.
  * Enabling /ZW (CompileAsWinRT) option for msvs
  * ninja/mac: Add horrible workaround for horrible Xcode 7.3 ld bug.
  * [gyp-ninja] Set simulator and device SDKROOT for iOS.
  * Ignore more Xcode stderr logging information.
  * Only call CopyStringsFile if convert_to_binary is False.
  * Fix :rfc1034identifier when the value contains underscore.
  * Complete PBXCopyFilesBuildPhase TODO in xcodeproj_file.py.
  * Make the ninja backend transitively check for C++ sources to use the C++ compiler for linking
  * Add new target type called windows_driver. * Modify GYP to set the PlatformToolset, the DriverType and the TargetVersion * Add msvs_target_version configuration
* Wed Jul  6 2016 mpluskal@suse.com
- Update to version 0+git.20160620:
  * [gyp-ninja] Set simulator and device SDKROOT for iOS.
  * Ignore more Xcode stderr logging information.
* Tue Jun 14 2016 mpluskal@suse.com
- Update to version 0+git.20160513:
  * Fix mac_tool.py copy-bundle-resource errors.
  * [iOS/OS X] Copy file instead of hard-linking them.
  * gyp-win-tool: Let LinkWrapper only transmogrify / when the host platform is Windows.
  * gyp-win-tool: Fix regression from my last change.
  * gyp-win-tool: Don't use shell=True on non-Windows hosts.
  * Fix header map nextPowerOf2 method.
  * [ios-ninja] Support xctests in devices in release.
  * Adds support for a new target spec: 'mac_xcuitest_bundle'. This allows us to create UI testing bundles.
  * Enabling /ZW (CompileAsWinRT) option for msvs
  * ninja/mac: Add horrible workaround for horrible Xcode 7.3 ld bug.
* Thu May  5 2016 mpluskal@suse.com
- Update to version 0+git.20160504:
  * [GN] Use hard-link if possible when copying to bundle.
* Tue May  3 2016 mpluskal@suse.com
- Update to version 0+git.20160426:
  * Support DEVELOPER_DIR in gyp-ninja for mac.
  * [GN] Use hard-link if possible when copying to bundle.
  * Fix mac_tool.py copy-bundle-resource errors.
  * [iOS/OS X] Copy file instead of hard-linking them.
  * gyp-win-tool: Let LinkWrapper only transmogrify / when the host platform is Windows.
  * gyp-win-tool: Fix regression from my last change.
  * gyp-win-tool: Don't use shell=True on non-Windows hosts.
  * Fix header map nextPowerOf2 method.
  * [ios-ninja] Support xctests in devices in release.
  * Adds support for a new target spec: 'mac_xcuitest_bundle'. This allows us to create UI testing bundles.
* Fri Apr 15 2016 mpluskal@suse.com
- Update to version 0+git.20160413:
  * ninja: Add target_rpath generator flag
  * Add support for iOS Frameworks with header maps.
  * Detect and warn on missing vcvarsall.bat
  * Support DEVELOPER_DIR in gyp-ninja for mac.
  * [GN] Use hard-link if possible when copying to bundle.
  * Fix mac_tool.py copy-bundle-resource errors.
  * [iOS/OS X] Copy file instead of hard-linking them.
  * gyp-win-tool: Let LinkWrapper only transmogrify / when the host platform is Windows.
  * gyp-win-tool: Fix regression from my last change.
  * gyp-win-tool: Don't use shell=True on non-Windows hosts.
* Sun Mar 20 2016 mpluskal@suse.com
- Update to version 0~git.20160318:
  + Revert "Update Xcode emulation extra plist items."
  + Re-land update Xcode emulation extra plist items for Xcode 7.2
  + Support sdk_version of None.
  + Don't recompute environment for mac bundles unnecessarily.
  + Make login.keychain and 'Provisioning Profiles' symlinks.
  + Fix tests with Xcode 7.
  + Xcode-ninja: Add excluded files to the project sources_for_indexing.xcodeproj
  + ninja/win: Use qualified paths for precompiled headers.
  + Adjust pretty_gyp to align comments with the appropriate braces.
  + ninja: Add target_rpath generator flag
- Small spec file cleanup
* Wed Mar  9 2016 mpluskal@suse.com
- Update to version 0~git.20160304:
  + [Mac/iOS] Add custom fonts, target device and minimum
    ployment target to _CopyXIBFile
  + Update Xcode emulation extra plist items.
  + Revert "Update Xcode emulation extra plist items."
  + Re-land update Xcode emulation extra plist items for Xcode 7.2
  + Support sdk_version of None.
  + Don't recompute environment for mac bundles unnecessarily.
  + Make login.keychain and 'Provisioning Profiles' symlinks.
  + Fix tests with Xcode 7.
  + Xcode-ninja: Add excluded files to the project
    urces_for_indexing.xcodeproj
  + ninja/win: Use qualified paths for precompiled headers.
- Add _service
- Cleanup spec file with spec-cleaner
* Sat Aug  8 2015 p.drouand@gmail.com
- Update to master latest revision
- Add python-setuptools dependency
- Add gyp-rpmoptflags.patch
* Mon Dec  3 2012 p.drouand@gmail.com
- Update to latest svn revision
* Wed Sep  5 2012 p.drouand@gmail.com
- Initial release
